@@ -254,3 +254,80 @@ def del_block_in_file(file_path, block_line_begin, block_line_end):
                 pass
             else:
                 print(line, end="")
+
+def full_page_snapshot(url, dir_snapshot):
+    from selenium import webdriver
+    from selenium.webdriver.common.by import By;
+    import time
+    import os
+    assert(os.path.isdir(dir_snapshot))
+    if 'http_proxy' in os.environ:
+        del os.environ['http_proxy']
+    chrome_options = webdriver.ChromeOptions()
+    driver = webdriver.Remote(
+        command_executor='http://127.0.0.1:4444/wd/hub',
+        options=chrome_options)
+    driver.maximize_window()
+    driver.get(url=url)
+    # Wait some time for page loading
+    time.sleep(4)
+    found_page_source = driver.page_source
+    try:
+        span_collapse = driver.find_element(by=By.XPATH, value = "//span[text()=\"«\"]")
+        span_collapse.click()
+    except Exception as e:
+        print(e)
+    driver.save_screenshot(dir_snapshot + os.path.sep + "screenshot.png")
+    
+    main_scroll_height = 0
+    main_scroll_top = 0
+    page_height = 0
+    flag_main_element = False
+    try:
+        main_scroll_height = driver.execute_script("return document.getElementById('MAIN').scrollHeight")
+        main_scroll_top = driver.execute_script("return document.getElementById('MAIN').scrollTop")    
+        page_height = driver.execute_script("return document.body.scrollHeight")
+        flag_main_element = True
+    except Exception as e:
+        print(e)
+        main_scroll_height = driver.execute_script('return document.body.parentNode.scrollHeight')
+        main_scroll_top = driver.execute_script('return document.body.parentNode.scrollTop')
+        page_height = driver.execute_script('return window.innerHeight')
+    
+    print("main_scroll_height is %d main_scroll_top is %d page_height is %d" % (main_scroll_height, main_scroll_top, page_height))
+    while True:
+        driver.execute_script("window.scrollBy(0, %d);" % page_height)
+        time.sleep(1)
+        if flag_main_element:
+            new_main_scroll_height = driver.execute_script("return document.getElementById('MAIN').scrollHeight")
+        else:
+            new_main_scroll_height = driver.execute_script('return document.body.parentNode.scrollHeight')
+        if new_main_scroll_height == main_scroll_height:
+            break
+        main_scroll_height = new_main_scroll_height
+        print("main_scroll_height is %d" % main_scroll_height)
+
+    driver.execute_script("window.scrollTo(0, 0);")
+    page_index = 1
+    driver.save_screenshot(dir_snapshot + os.path.sep + ("page_%06d.png"%page_index))
+    
+    if flag_main_element:
+        main_scroll_height = driver.execute_script("return document.getElementById('MAIN').scrollHeight")
+        page_height = driver.execute_script("return document.body.scrollHeight")
+    else:
+        main_scroll_height = driver.execute_script("return document.documentElement.scrollHeight")
+        page_height = driver.execute_script('return window.innerHeight')
+    
+    window_page_y_offset = driver.execute_script("return window.pageYOffset")
+    print("page_index is %d window_page_y_offset is %d main_scroll_height is %d page_height is %d" % (page_index, window_page_y_offset, main_scroll_height, page_height))
+    
+    while ((window_page_y_offset + page_height < main_scroll_height) and (page_index < 100)):
+        driver.execute_script("window.scrollBy(0, %d);" % page_height)
+        page_index = page_index + 1
+        driver.save_screenshot(dir_snapshot + os.path.sep + ("page_%06d.png"%page_index))
+        window_page_y_offset = driver.execute_script("return window.pageYOffset")
+        print("page_index is %d window_page_y_offset is %d main_scroll_height is %d page_height is %d" % (page_index, window_page_y_offset, main_scroll_height, page_height))
+    assert(page_index < 100)
+    driver.save_screenshot(dir_snapshot + os.path.sep + "screenshot_last_page.png")
+    driver.close()
+    return page_index
